==> Refine-0.1.1.tar.gz: Refine-0.1.1/refine/main.py <==
# main.py
#
# Copyright 2024 Hari Rana (TheEvilSkeleton)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# SPDX-License-Identifier: GPL-3.0-or-later


import logging
import sys

import gi

gi.require_version("Gtk", "4.0")
gi.require_version("Adw", "1")
gi.require_version("Xdp", "1.0")
gi.require_version("Pango", "1.0")
gi.require_version("XdpGtk4", "1.0")

from gettext import gettext as _
from typing import Any, Optional

from gi.repository import Adw, Gio, GLib, Gtk

from refine.profile import APP_ID, MAJOR, MICRO, PROFILE
from refine.utils import RefineSettingsSource, create_schema_source, get_debug_info
from refine.window import RefineWindow


class RefineApplication(Adw.Application):
    """The main application singleton class."""

    def __init__(self) -> None:
        super().__init__(
            application_id=APP_ID,
            flags=Gio.ApplicationFlags.DEFAULT_FLAGS,
            resource_base_path="/page/tesk/Refine",
        )
        self.create_action("quit", lambda *_: self.quit(), ["<primary>q"])
        self.create_action("about", self.on_about_action)

        self.source: Optional[Gio.SettingsSchemaSource] = create_schema_source()
        self.settings: dict[str, RefineSettingsSource] = {}

    def do_activate(self) -> None:
        """Called when the application is activated.

        We raise the application's main window, creating it if
        necessary.
        """
        win = self.props.active_window
        if not win:
            win = RefineWindow(application=self)

        if GLib.getenv("XDG_CURRENT_DESKTOP") != "GNOME":
            dialog = Adw.AlertDialog.new(
                heading=_("Unsupported Environment"),
                body=_("Refine only supports running under GNOME"),
            )

            dialog.add_response("close", _("Close"))
            dialog.connect("response", lambda *_: sys.exit(1))

            dialog.present()
        else:
            # `win` needs to be initialized outside of the if block
            win.present()

        if PROFILE == "development":
            logging.getLogger().setLevel(logging.DEBUG)
            win.add_css_class("devel")

    def on_about_action(self, *args: Any) -> None:
        """Callback for the app.about action."""
        about = Adw.AboutDialog.new_from_appdata(
            "/page/tesk/Refine/appdata", f"{MAJOR}.{MICRO}.0"
        )

        # Translators: Replace "translator-credits" with your name/username, and optionally an email or URL.
        about.set_translator_credits(_("translator-credits"))
        about.set_copyright(_("Copyright © 2024 Hari Rana (TheEvilSkeleton)"))
        about.add_other_app(  # type: ignore [attr-defined]
            "com.usebottles.bottles", _("Bottles"), _("Run Windows software")
        )
        about.add_other_app(  # type: ignore [attr-defined]
            "io.gitlab.theevilskeleton.Upscaler",
            _("Upscaler"),
            _("Upscale and enhance images"),
        )
        about.set_developers(
            [
                f"{about.get_developer_name()} https://tesk.page",
                "Evelyn Serra (itsEve) https://itseve.xyz",
            ]
        )
        about.set_artists(["Dominik Baran https://gitlab.gnome.org/toad"])
        about.set_debug_info(get_debug_info())
        about.present(self.props.active_window)

    def create_action(self, name, callback, shortcuts=None) -> None:
        """Add an application action.

        Args:
            name: the name of the action
            callback: the function to be called when the action is
              activated
            shortcuts: an optional list of accelerators
        """
        action = Gio.SimpleAction.new(name, None)
        action.connect("activate", callback)
        self.add_action(action)
        if shortcuts:
            self.set_accels_for_action(f"app.{name}", shortcuts)


def main(version) -> int:
    """The application's entry point."""
    app = RefineApplication()
    return app.run(sys.argv)

==> Refine-0.3.0.tar.gz: Refine-0.3.0/refine/main.py <==
# main.py
#
# Copyright 2024 Hari Rana (TheEvilSkeleton)
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
# SPDX-License-Identifier: GPL-3.0-or-later


import logging
import sys

import gi

gi.require_version("Gtk", "4.0")
gi.require_version("Adw", "1")
gi.require_version("Xdp", "1.0")
gi.require_version("Pango", "1.0")
gi.require_version("XdpGtk4", "1.0")

from gettext import gettext as _
from typing import Any

from gi.repository import Adw, Gio, GLib, Gtk

from refine.profile import APP_ID, MAJOR, MINOR, PROFILE
from refine.utils import (
    RefineSettingsSource,
    get_debug_info,
    create_schema_sources_list,
)
from refine.window import RefineWindow


class RefineApplication(Adw.Application):
    """The main application singleton class."""

    def __init__(self) -> None:
        super().__init__(
            application_id=APP_ID,
            flags=Gio.ApplicationFlags.DEFAULT_FLAGS,
            resource_base_path="/page/tesk/Refine",
        )
        self.create_action("quit", lambda *_: self.quit(), ["<primary>q"])
        self.create_action("about", self.on_about_action)

        self.sources: list[Gio.SettingsSchemaSource] = create_schema_sources_list()
        self.settings: dict[str, RefineSettingsSource] = {}

    def do_activate(self) -> None:
        """Called when the application is activated.

        We raise the application's main window, creating it if
        necessary.
        """
        win = self.props.active_window
        if not win:
            win = RefineWindow(application=self)

        win.present()

        if PROFILE == "development":
            logging.getLogger().setLevel(logging.DEBUG)
            win.add_css_class("devel")

    def on_about_action(self, *args: Any) -> None:
        """Callback for the app.about action."""
        about = Adw.AboutDialog.new_from_appdata(
            "/page/tesk/Refine/appdata", f"{MAJOR}.{MINOR}.0"
        )

        # Translators: Replace "translator-credits" with your name/username, and optionally an email or URL.
        about.set_translator_credits(_("translator-credits"))
        about.set_copyright(_("Copyright © 2024 Hari Rana (TheEvilSkeleton)"))
        about.add_other_app(  # type: ignore [attr-defined]
            "com.usebottles.bottles",
            _("Bottles"),
            _("Run Windows software"),
        )
        about.add_other_app(  # type: ignore [attr-defined]
            "io.gitlab.theevilskeleton.Upscaler",
            _("Upscaler"),
            _("Upscale and enhance images"),
        )
        about.set_developers(
            [
                f"{about.get_developer_name()} https://tesk.page",
                "Evelyn Serra (itsEve) https://itseve.xyz",
            ]
        )
        about.set_artists(["Dominik Baran https://gitlab.gnome.org/toad"])
        about.set_debug_info(get_debug_info())
        about.present(self.props.active_window)

    def create_action(self, name, callback, shortcuts=None) -> None:
        """Add an application action.

        Args:
            name: the name of the action
            callback: the function to be called when the action is
              activated
            shortcuts: an optional list of accelerators
        """
        action = Gio.SimpleAction.new(name, None)
        action.connect("activate", callback)
        self.add_action(action)
        if shortcuts:
            self.set_accels_for_action(f"app.{name}", shortcuts)


def main(version) -> int:
    """The application's entry point."""
    app = RefineApplication()
    return app.run(sys.argv)
